package members

import (
	base_ctl "SCRM/controllers"
	"SCRM/enums"
	"SCRM/models"
	"SCRM/service/member_service"
	"SCRM/utils"
	"reflect"
	"time"

	"encoding/json"

	"github.com/astaxie/beego"
)

func TagCtlRegistRouters() {
	beego.Router("/api/member/tag/edit", &TagAPIController{}, "Post:EditMemberTags")
	beego.Router("/api/members/tags/add", &TagAPIController{}, "Post:AddMembersTags")
	beego.Router("/api/members/tags", &TagAPIController{}, "Get:GetTags")
	beego.Router("/api/members/tag/create", &TagAPIController{}, "Post:CreateTag")
	beego.Router("/api/members/tag/edit", &TagAPIController{}, "Put:EditTag")
	beego.Router("/api/members/tags/delete", &TagAPIController{}, "Delete:DeleteTag")
}

type TagAPIController struct {
	base_ctl.BaseAuthAPIController
}

func (c *TagAPIController) EditMemberTags() {
	id, _ := c.GetInt64("id", 0)
	if id <= 0 {
		c.ServeFailJsonSend(enums.ErrorCodeParamWrong, "参数错误:id")
		return
	}
	adminUserInfo := c.GetAdminUserInfo()
	member, err := member_service.GetOnlyMemberByID(adminUserInfo.CurrentOrgId, id)
	if err != nil {
		c.ServeFailJsonSend(enums.ErrorCodeDBUpdate, "编辑会员标签失败:（"+err.Error()+"）")
		return
	}
	if member == nil {
		c.ServeFailJsonSend(enums.ErrorCodeDBUpdate, "编辑会员标签失败:（会员记录不存在）")
		return
	}

	timeNow := time.Now().Unix()

	dataBody := make(map[string]interface{}, 0)
	err = json.Unmarshal(c.Ctx.Input.RequestBody, &dataBody)
	if err != nil {
		utils.ErrorLog(err.Error())
		c.ServeFailJsonSend(enums.ErrorCodeParamWrong, "参数错误")
		return
	}

	if dataBody["tags"] == nil || reflect.TypeOf(dataBody["tags"]).String() != "[]interface {}" {
		c.ServeFailJsonSend(enums.ErrorCodeParamWrong, "缺少参数:tags")
		return
	}

	returnData := make(map[string]interface{}, 0)

	tagsInters := dataBody["tags"].([]interface{})
	if len(tagsInters) == 0 {
		err = member_service.DeleteMemeberAllTags(adminUserInfo.CurrentOrgId, member.ID)
		if err != nil {
			c.ServeFailJsonSend(enums.ErrorCodeDBUpdate, "编辑会员标签失败：（"+err.Error()+"）")
			return
		}
		returnData["tags"] = nil
	} else {
		userTags := make([]*models.UserTagLinks, 0)
		tagIds := make([]int64, 0)
		tagIDMap := make(map[int64]int64, 0)
		for _, tagsInter := range tagsInters {
			id := int64(tagsInter.(float64))
			tagIds = append(tagIds, id)
			tagIDMap[id] = id
		}
		allTags, err := member_service.GetMemberAllTags(adminUserInfo.CurrentOrgId, member.ID)
		if err != nil {
			c.ServeFailJsonSend(enums.ErrorCodeDBUpdate, "编辑会员标签失败：（"+err.Error()+"）")
			return
		}
		oldTagIDMap := make(map[int64]int64, 0)
		for _, tagItem := range allTags {
			item := *tagItem
			item.Status = 1
			if _, exist := tagIDMap[item.TagId]; !exist {
				item.Status = 0
				item.UpdatedTime = timeNow
			}
			userTags = append(userTags, &item)
			oldTagIDMap[item.TagId] = item.TagId
		}

		for _, id := range tagIDMap {
			if _, exist := oldTagIDMap[id]; exist {
				continue
			}
			var tagItem models.UserTagLinks
			tagItem.UserOrgId = adminUserInfo.CurrentOrgId
			tagItem.TagId = id
			tagItem.UserLinkId = member.ID
			tagItem.Status = 1
			tagItem.UpdatedTime = timeNow
			tagItem.CreatedTime = timeNow
			userTags = append(userTags, &tagItem)
		}
		err = member_service.SaveMemberTags(userTags)

		if err != nil {
			c.ServeFailJsonSend(enums.ErrorCodeDBUpdate, "编辑会员标签失败：（"+err.Error()+"）")
			return
		}

		returnData["tags"] = tagIds
	}
	c.ServeSuccessJSON(returnData)
	return
}

func (c *TagAPIController) AddMembersTags() {
	adminUserInfo := c.GetAdminUserInfo()
	timeNow := time.Now().Unix()

	dataBody := make(map[string]interface{}, 0)
	err := json.Unmarshal(c.Ctx.Input.RequestBody, &dataBody)
	if err != nil {
		utils.ErrorLog(err.Error())
		c.ServeFailJsonSend(enums.ErrorCodeParamWrong, "参数错误")
		return
	}

	if dataBody["tags"] == nil || reflect.TypeOf(dataBody["tags"]).String() != "[]interface {}" {
		c.ServeFailJsonSend(enums.ErrorCodeParamWrong, "缺少参数:tags")
		return
	}

	idsInters := dataBody["ids"].([]interface{})
	if len(idsInters) == 0 {
		if err != nil {
			c.ServeFailJsonSend(enums.ErrorCodeDBCreate, "添加会员标签失败:（没有选择会员）")
			return
		}
	}

	ids := make([]int64, 0)
	idsMap := make(map[int64]int64, 0)
	for _, idsInter := range idsInters {
		id := int64(idsInter.(float64))
		ids = append(ids, id)
		idsMap[id] = id
	}

	tagsInters := dataBody["tags"].([]interface{})
	if len(tagsInters) == 0 {
		if err != nil {
			c.ServeFailJsonSend(enums.ErrorCodeDBCreate, "添加会员标签失败:（没有选择标签）")
			return
		}
	}
	tagIds := make([]int64, 0)
	tagIDMap := make(map[int64]int64, 0)
	for _, tagsInter := range tagsInters {
		id := int64(tagsInter.(float64))
		tagIds = append(tagIds, id)
		tagIDMap[id] = id
	}

	allTags, err := member_service.GetMembersAllTags(adminUserInfo.CurrentOrgId, ids)
	if err != nil {
		c.ServeFailJsonSend(enums.ErrorCodeDBCreate, "添加会员标签失败:（"+err.Error()+"）")
		return
	}

	userTags := make([]*models.UserTagLinks, 0)
	oldTagIDMap := make(map[int64]map[int64]int64, 0)
	for _, tagItem := range allTags {
		_, exist := tagIDMap[tagItem.TagId]
		_, uexist := idsMap[tagItem.UserLinkId]
		if exist && uexist {
			item := *tagItem
			item.Status = 1
			item.UpdatedTime = timeNow
			userTags = append(userTags, &item)
			if _, oex := oldTagIDMap[item.UserLinkId]; !oex {
				oldTagIDMap[item.UserLinkId] = make(map[int64]int64, 0)
			}
			oldTagIDMap[item.UserLinkId][item.TagId] = item.TagId
		}
	}

	for _, userid := range idsMap {
		for _, tagid := range tagIDMap {
			if _, exist := oldTagIDMap[userid]; exist {
				if _, exist := oldTagIDMap[userid][tagid]; exist {
					continue
				}
			}
			var tagItem models.UserTagLinks
			tagItem.UserOrgId = adminUserInfo.CurrentOrgId
			tagItem.TagId = tagid
			tagItem.UserLinkId = userid
			tagItem.Status = 1
			tagItem.UpdatedTime = timeNow
			tagItem.CreatedTime = timeNow
			userTags = append(userTags, &tagItem)
		}
	}
	err = member_service.SaveMemberTags(userTags)

	if err != nil {
		c.ServeFailJsonSend(enums.ErrorCodeDBCreate, "添加会员标签失败：（"+err.Error()+"）")
		return
	}

	returnData := make(map[string]interface{}, 0)
	returnData["msg"] = "ok"

	c.ServeSuccessJSON(returnData)
	return
}

func (c *TagAPIController) GetTags() {
	page, _ := c.GetInt64("page", 1)
	limit, _ := c.GetInt64("limit", 10)
	searchKey := c.GetString("search", "")
	if page <= 0 {
		page = 1
	}
	if limit <= 0 {
		limit = 10
	}

	adminUserInfo := c.GetAdminUserInfo()
	tags, total, _ := member_service.GetPageTagList(adminUserInfo.CurrentOrgId, page, limit, searchKey)

	returnData := make(map[string]interface{}, 0)
	returnData["tags"] = tags
	returnData["total"] = total
	c.ServeSuccessJSON(returnData)
	return
}

func (c *TagAPIController) CreateTag() {
	adminUserInfo := c.GetAdminUserInfo()
	timeNow := time.Now().Unix()

	dataBody := make(map[string]interface{}, 0)
	err := json.Unmarshal(c.Ctx.Input.RequestBody, &dataBody)
	if err != nil {
		utils.ErrorLog(err.Error())
		c.ServeFailJsonSend(enums.ErrorCodeParamWrong, "参数错误")
		return
	}

	var tag models.UserTags

	if dataBody["tag_name"] == nil || reflect.TypeOf(dataBody["tag_name"]).String() != "string" {
		c.ServeFailJsonSend(enums.ErrorCodeParamWrong, "缺少参数:标签名")
		return
	}
	tagName, _ := dataBody["tag_name"].(string)
	if len(tagName) == 0 {
		c.ServeFailJsonSend(enums.ErrorCodeParamWrong, "标签名不能为空")
		return
	}
	tag.TagName = tagName

	oldTag, err := member_service.FindTagByName(adminUserInfo.CurrentOrgId, tagName)
	if err != nil {
		c.ServeFailJsonSend(enums.ErrorCodeDBCreate, "添加标签失败:（"+err.Error()+"）")
		return
	}
	if oldTag != nil {
		c.ServeFailJsonSend(enums.ErrorCodeDBCreate, "添加标签失败:（已经存在同名的标签）")
		return
	}
	tag.Status = 1
	tag.UserOrgId = adminUserInfo.CurrentOrgId
	tag.CreatedTime = timeNow
	tag.UpdatedTime = timeNow

	err = member_service.SaveTag(&tag)
	if err != nil {
		c.ServeFailJsonSend(enums.ErrorCodeDBCreate, "添加标签失败:（"+err.Error()+"）")
		return
	}

	returnData := make(map[string]interface{}, 0)
	returnData["tag"] = tag
	c.ServeSuccessJSON(returnData)
	return
}

func (c *TagAPIController) EditTag() {
	id, _ := c.GetInt64("id", 0)
	if id <= 0 {
		c.ServeFailJsonSend(enums.ErrorCodeParamWrong, "参数错误:id")
		return
	}
	adminUserInfo := c.GetAdminUserInfo()
	timeNow := time.Now().Unix()

	dataBody := make(map[string]interface{}, 0)
	err := json.Unmarshal(c.Ctx.Input.RequestBody, &dataBody)
	if err != nil {
		utils.ErrorLog(err.Error())
		c.ServeFailJsonSend(enums.ErrorCodeParamWrong, "参数错误")
		return
	}

	tag, err := member_service.FindOnlyTagByID(adminUserInfo.CurrentOrgId, id)
	if err != nil {
		c.ServeFailJsonSend(enums.ErrorCodeDBUpdate, "编辑标签失败:（"+err.Error()+"）")
		return
	}
	if tag == nil {
		c.ServeFailJsonSend(enums.ErrorCodeDBUpdate, "编辑标签失败:（标签不存在）")
		return
	}

	if dataBody["tag_name"] == nil || reflect.TypeOf(dataBody["tag_name"]).String() != "string" {
		c.ServeFailJsonSend(enums.ErrorCodeParamWrong, "缺少参数:标签名")
		return
	}
	tagName, _ := dataBody["tag_name"].(string)
	if len(tagName) == 0 {
		c.ServeFailJsonSend(enums.ErrorCodeParamWrong, "标签名不能为空")
		return
	}
	tag.TagName = tagName

	oldTag, err := member_service.FindTagByName(adminUserInfo.CurrentOrgId, tagName)
	if err != nil {
		c.ServeFailJsonSend(enums.ErrorCodeDBCreate, "编辑标签失败:（"+err.Error()+"）")
		return
	}
	if oldTag != nil && oldTag.ID != tag.ID {
		c.ServeFailJsonSend(enums.ErrorCodeDBCreate, "编辑标签失败:（已经存在同名的标签）")
		return
	}
	tag.UpdatedTime = timeNow

	err = member_service.SaveTag(tag)
	if err != nil {
		c.ServeFailJsonSend(enums.ErrorCodeDBCreate, "编辑标签失败:（"+err.Error()+"）")
		return
	}

	returnData := make(map[string]interface{}, 0)
	returnData["tag"] = tag
	c.ServeSuccessJSON(returnData)
	return
}

func (c *TagAPIController) DeleteTag() {
	adminUserInfo := c.GetAdminUserInfo()

	dataBody := make(map[string]interface{}, 0)
	err := json.Unmarshal(c.Ctx.Input.RequestBody, &dataBody)
	if err != nil {
		utils.ErrorLog(err.Error())
		c.ServeFailJsonSend(enums.ErrorCodeParamWrong, "参数错误")
		return
	}

	idsInters := dataBody["ids"].([]interface{})
	if len(idsInters) == 0 {
		if err != nil {
			c.ServeFailJsonSend(enums.ErrorCodeDBDelete, "删除标签失败:（没有选择标签）")
			return
		}
	}

	ids := make([]int64, 0)
	for _, idsInter := range idsInters {
		id := int64(idsInter.(float64))
		ids = append(ids, id)
	}

	err = member_service.DeleteTags(adminUserInfo.CurrentOrgId, ids)
	if err != nil {
		c.ServeFailJsonSend(enums.ErrorCodeDBDelete, "删除标签失败:（"+err.Error()+"）")
		return
	}

	returnData := make(map[string]interface{}, 0)
	returnData["msg"] = "ok"

	c.ServeSuccessJSON(returnData)
	return
}
