package models

type Role struct {
	Id           int64  `gorm:"PRIMARY_KEY;AUTO_INCREMENT" json:"id"`
	RoleName     string `gorm:"column:role_name" json:"name"`
	RoleIntro    string `gorm:"column:role_introduction" json:"intro"`
	Creator      int64  `json:"-"`
	OrgId        int64  `gorm:"column:org_id" json:"-"`
	AppId        int64  `gorm:"column:app_id" json:"-"`
	IsSuperAdmin bool   `gorm:"column:is_super_admin" json:"-"`
	Status       int8   `json:"status"`                // 状态 0.无效 1.有效 2.禁用
	CreateTime   int64  `gorm:"column:ctime" json:"-"` // 创建时间
	ModifyTime   int64  `gorm:"column:mtime" json:"-"` // 修改时间
}

func (Role) TableName() string {
	return "sgj_user_role"
}

type App_Role struct {
	Id          int64  `gorm:"PRIMARY_KEY;AUTO_INCREMENT" json:"id"`
	AdminUserId int64  `gorm:"column:admin_user_id" json:"admin_user_id"`
	OrgId       int64  `gorm:"column:org_id" json:"org_id"`
	AppId       int64  `gorm:"column:app_id" json:"app_id"`
	RoleId      int64  `gorm:"column:role_id" json:"role_id"`
	Avatar      string `json:"avatar" json:"avatar"`
	UserName    string `gorm:"column:user_name" json:"user_name"`   // 用户名称
	Intro       string `json:"intro"`                               // 简介
	UserType    int8   `gorm:"column:user_type" json:"user_type"`   // 用户类型（1.管理员；2.医生；3.护士；4.运营）
	UserTitle   int8   `gorm:"column:user_title" json:"user_title"` // 用户职称（1.医士；2.医师；3.住院医师；4.主治医师；5.副主任医师；6.主任医师；7.护士；8.护师；9.主管护师；10.副主任护师；11.主任护师；12.运营专员；13.运营主管）
	Status      int8   `json:"status"`                              // 状态 0.无效 1.有效
	CreateTime  int64  `gorm:"column:ctime" json:"ctime"`           // 创建时间
	ModifyTime  int64  `gorm:"column:mtime" json:"mtime"`           // 修改时间
}

func (App_Role) TableName() string {
	return "sgj_user_admin_role"
}

var UserType = map[int]string{
	1: "管理员",
	2: "医生",
	3: "护士",
	4: "运营",
}

var UserTitle = map[int]string{
	1:  "医士",
	2:  "医师",
	3:  "住院医师",
	4:  "主治医师",
	5:  "副主任医师",
	6:  "主任医师",
	7:  "护士",
	8:  "护师",
	9:  "主管护师",
	10: "副主任护师",
	11: "主任护师",
	12: "运营专员",
	13: "运营主管",
}
